/*Copyright (C) 2010 Deveaux Duncan

This file is part of Hikou no mizu.

Hikou no mizu is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Hikou no mizu is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Hikou no mizu.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef DEF_ANIMATION
#define DEF_ANIMATION

#include <SFML/Graphics.hpp>
#include <string>
#include <vector>
#include <sstream>

#include "Engines/Resources/ImageManager.hpp" //static loadFromDir method

//Class representing an animation by stocking frames in m_framesList.
class Animation
{   
    public:
        Animation();
        void render(sf::RenderWindow &renderWindow);
        
        void addFrame(sf::Image &frame, int frameIx = -1);
        void removeFrame(int frameIx);
        
        void goToFrame(int frameIx);
        void next();
        void previous();
        
        //Get and set methods
        int getFramesNo() const;
        int getCurrentFrameIx() const; 
        
        void setOrigin(const sf::Vector2f &origin);
        const sf::Vector2f &getOrigin() const;
        
        void flipX(bool flip);

        float getWidth() const;
        float getHeight() const;
        
        void setXPosition(float position);
        float getXPosition() const;
        void setYPosition(float position);
        float getYPosition() const;
        
        //Static methods
        static Animation loadFromDir(const std::string &dirPath, int framesNo);
    
    private:
        std::vector<sf::Image*> m_framesList;
        sf::Sprite m_renderImage;
        int m_ixFrame;
};

#endif