/*Copyright (C) 2010 Deveaux Duncan

This file is part of Hikou no mizu.

Hikou no mizu is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Hikou no mizu is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Hikou no mizu.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "SoundEngine.hpp"

SoundEngine::SoundEngine() : m_volume(100)
{
    
}

void SoundEngine::playSound(const std::string &soundPath)
{
    m_playingSounds.push_back( make_pair(loadSound(soundPath), soundPath) );
    m_playingSounds.back().first.Play();
}

void SoundEngine::update()
{
    std::list< std::pair<sf::Sound, std::string> >::iterator it = m_playingSounds.begin();
    
    while (it != m_playingSounds.end())
    {
        if ((*it).first.GetStatus() != sf::Sound::Playing)
            it = m_playingSounds.erase(it);
        else
            it++;
    }
}

void SoundEngine::setVolume(float volume)
{
    if (volume >= 0 && volume <= 100)
        m_volume = volume;
}

sf::Sound SoundEngine::loadSound(const std::string &soundPath)
{
    //Get sound buffer's manager
    SoundBufferManager *soundBufferManager = SoundBufferManager::getInstance();
    
    //Load sound
    sf::Sound sound;
    sound.SetBuffer( *soundBufferManager->getSoundBuffer(soundPath) );
    sound.SetVolume(m_volume);
    
    return sound;
}