/*Copyright (C) 2010 Deveaux Duncan

This file is part of Hikou no mizu.

Hikou no mizu is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Hikou no mizu is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Hikou no mizu.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef DEF_FIGHT
#define DEF_FIGHT

#include <SFML/Graphics.hpp>
#include <sstream>

#include "Configuration/Configuration.hpp"

#include "Engines/Physics/PhysicsEngine.hpp"
#include "Engines/Sound/SoundEngine.hpp"

#include "GUI/Complex/FightInterface.hpp"
#include "Arena/Arena.hpp"
#include "Player/AI.hpp"
#include "Player/Human.hpp"

#include "Screens/Screen.hpp"

class GameEngine;

//Screen's inheriting class representing the fight screen
class Fight : public Screen
{
    public:
        Fight(GameEngine *gameEngine);
        ~Fight();
        
        void setArena(const std::string &arenaName);
        
        void addPlayer(const std::string &playerName, int playerType);
        void clearPlayers();
        
        //Screen virtual method
        void run();
    
    private:
        void updatePlayers();
        void renderPlayers(sf::RenderWindow &renderWindow);
        
        void deletePlayers();
        
        GameEngine *m_gameEngine;
        
        sf::RenderWindow *m_renderWindow;
        Configuration *m_configuration;
        
        std::vector<Player*> m_playersList;
        Arena m_arena;
        
        sf::View m_gameView;
        sf::Text m_fpsText;
        
        FightInterface m_interface;
        
        PhysicsEngine m_physicsEngine;
        SoundEngine m_soundEngine;
};

#endif